# Dyson Python Library

[![codecov](https://codecov.io/gh/libdyson-wg/libdyson-neon/branch/main/graph/badge.svg?token=v2OypI2WaI)](https://codecov.io/gh/libdyson-wg/libdyson-neon)

This library is meant to continue the development of [libdyson](https://github.com/shenxn/libdyson) by a community of maintainers. Thanks to [@shenxn](https://github.com/shenxn) for their initial work making this possible.
